caellion-python-commons: caellion.pycommons.hashing.file_hashing Namespace Reference

caellion-python-commons

Classes
caellion.pycommons.hashing.file_hashing Namespace Reference

This module provides utilities related to hashing files. More...

## Classes
class | UnsupportedAlgorithmException
| This exception is raised whenever provided algorithm is not one of allowed algorithms. More...
class | AlreadyDoneException
| This exception is raised when hashing was requested on a FileHasher that has already finished hashing. More...
class | NotDoneYetException
| This exception is raised when a hash was requested from a FileHasher that has not hashed any file yet. More...
class | FileHasher
| This class provides hashlib-based file hasher. More...

## Detailed Description

This module provides utilities related to hashing files.